@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-""" glogarchive v 0.7 (C) 2010 by Kurt Fleisch
+""" glogarchive v 0.8 (C) 2010 by Kurt Fleisch
     http://www.bananenfisch.net/n900/
 
     This program is free software: you can redistribute it and/or modify
@@ -21,8 +21,9 @@ import pygtk
 pygtk.require('2.0')
 import sys, os, shutil, sqlite3, time, gtk, hildon, cgi, csv, osso
 
-EL_PATH = "/home/user/.rtcom-eventlogger/el.db"
-ARCHIVE_PATH = "/home/user/.rtcom-eventlogger/el_archive.db"
+EL_PATH = "/home/user/.rtcom-eventlogger/el-v1.db"
+ARCHIVE_PATH = "/home/user/.rtcom-eventlogger/el_archive-v1.db"
+ARCHIVE_OLD = "/home/user/.rtcom-eventlogger/el_archive.db"
 
 class fenster:
 
@@ -35,7 +36,7 @@ class fenster:
         self.about.set_name("glogarchive")
         self.about.set_logo_icon_name("glogarchive")
         self.about.set_comments("to archive SMS/IM messages and calling-history from the eventlogger to an extra DB")
-        self.about.set_version("0.7")
+        self.about.set_version("0.8")
         self.about.set_copyright("by Kurt Fleisch")
         gtk.about_dialog_set_url_hook(self.openurl, self.about)
         self.about.set_website("www.bananenfisch.net/n900")
@@ -62,121 +63,165 @@ class fenster:
     def __init__(self):
         self.archivedb = True
         self.viewall = True
+        self.allok = True
         self.window = hildon.StackableWindow()
         self.window.set_title("glogarchive")
         self.window.connect("delete_event", self.close_application)
         self.window.set_border_width(0)
 
-        self.osso_c = osso.Context("glogarchive", "0.7", False)
+        self.osso_c = osso.Context("glogarchive", "0.8", False)
         self.osso_rpc = osso.Rpc(self.osso_c)
 
-        gmenu = hildon.AppMenu()
+        if os.path.isfile(EL_PATH):
+          if os.path.isfile(ARCHIVE_OLD) and not os.path.isfile(ARCHIVE_PATH):
+            shutil.copy(ARCHIVE_OLD, ARCHIVE_PATH)
+            os.remove(ARCHIVE_OLD)
+            conn = sqlite3.connect(ARCHIVE_PATH)
+            conn2 = sqlite3.connect(EL_PATH)
+            dbchange = conn.cursor()
+            dbread = conn2.cursor()
 
-        butabout = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "About")
-        butabout.connect("clicked", self.show_about)
-        gmenu.append(butabout)
-        butdonate = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Donate")
-        butdonate.connect("clicked", self.show_donate)
-        gmenu.append(butdonate)
+            dbchange.execute("ALTER TABLE Events ADD outgoing BOOL DEFAULT 0")
+            dbchange.execute("ALTER TABLE Events ADD mc_profile BOOL DEFAULT 0")
+            dbchange.execute("DELETE FROM EventTypes")
+            conn.commit()
 
-        butdrop = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Drop Archive")
-        butdrop.connect("clicked", drop_archive)
-        gmenu.append(butdrop)
-        butquit = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Quit")
-        butquit.connect("clicked", self.close_application)
-        gmenu.append(butquit)
+            dbread.execute("SELECT * FROM EventTypes")
+            for row in dbread:
+              dbchange.execute("INSERT INTO EventTypes VALUES (?,?,?,?)", row)
+            conn.commit()
 
-        gmenu.show_all()
-        self.window.set_app_menu(gmenu)
+            dbchange.execute("UPDATE Events SET event_type_id = 1, outgoing = 1 WHERE event_type_id = 2")
+            dbchange.execute("UPDATE Events SET event_type_id = 5, outgoing = 1 WHERE event_type_id = 6")
+            dbchange.execute("UPDATE Events SET event_type_id = 7, outgoing = 1 WHERE event_type_id = 8")
 
-        columns = gtk.HBox(False, 0)
+            conn.commit()
+            dbchange.close()
+            dbread.close()
 
-        boxlines = gtk.VBox(False, 0)
+            infobox = gtk.VBox(False, 0)
+            infolabel = gtk.Label("Your archive have been updated now.\nPlease restart glogarchive.")
+            infobox.pack_start(infolabel, True, True, 0)
+            infolabel.show()
+            infobox.show()
+            self.window.add(infobox)
+            self.allok = False
+          else:
+            gmenu = hildon.AppMenu()
 
-        butarch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Archive new Events now!")
-        butarch.connect("clicked", archive)
-        boxlines.pack_start(butarch, False, False, 0)
-        butarch.show()
+            butabout = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "About")
+            butabout.connect("clicked", self.show_about)
+            gmenu.append(butabout)
+            butdonate = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Donate")
+            butdonate.connect("clicked", self.show_donate)
+            gmenu.append(butdonate)
 
-        self.outlines = gtk.VBox(False, 0)
-        scrolled_window = hildon.PannableArea()
-        boxlines.pack_start(scrolled_window, True, True, 0)
-        scrolled_window.show()
-        scrolled_window.add_with_viewport(self.outlines)
-        self.outlines.show()
+            butdrop = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Drop Archive")
+            butdrop.connect("clicked", drop_archive)
+            gmenu.append(butdrop)
+            butquit = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Quit")
+            butquit.connect("clicked", self.close_application)
+            gmenu.append(butquit)
 
-        datebox = gtk.HBox(False, 0)
+            gmenu.show_all()
+            self.window.set_app_menu(gmenu)
 
-        self.butfrom = hildon.DateButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        self.butfrom.set_text("From", "")
-        self.butfrom.connect("value-changed", listall, True)
-        datebox.pack_start(self.butfrom, True, True, 0)
-        self.butfrom.show()
+            columns = gtk.HBox(False, 0)
 
-        self.butto = hildon.DateButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        self.butto.set_text("To", "")
-        self.butto.connect("value-changed", listall, True)
-        datebox.pack_start(self.butto, True, True, 0)
-        self.butto.show()
+            boxlines = gtk.VBox(False, 0)
 
-        butdate = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "View All")
-        butdate.connect("clicked", listall)
-        datebox.pack_start(butdate, True, True, 0)
-        butdate.show()
+            butarch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Archive new Events now!")
+            butarch.connect("clicked", archive)
+            boxlines.pack_start(butarch, False, False, 0)
+            butarch.show()
 
-        boxlines.pack_start(datebox, False, False, 0)
-        datebox.show()
+            self.outlines = gtk.VBox(False, 0)
+            scrolled_window = hildon.PannableArea()
+            boxlines.pack_start(scrolled_window, True, True, 0)
+            scrolled_window.show()
+            scrolled_window.add_with_viewport(self.outlines)
+            self.outlines.show()
 
-        boxlines.show()
+            datebox = gtk.HBox(False, 0)
 
-        left = gtk.VBox(False, 0)
+            self.butfrom = hildon.DateButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+            self.butfrom.set_text("From", "")
+            self.butfrom.connect("value-changed", listall, True)
+            datebox.pack_start(self.butfrom, True, True, 0)
+            self.butfrom.show()
 
-        self.butcharch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Switch to Live-Database")
-        self.butcharch.connect("clicked", change_db)
-        left.pack_start(self.butcharch, False, False, 0)
-        self.butcharch.show()
-        self.labdb = gtk.Label()
-        self.labdb.set_markup("You are viewing:\n<big><b><i>The Archive</i></b></big>")
-        self.labdb.set_justify(gtk.JUSTIFY_CENTER)
-        left.pack_start(self.labdb, False, False, 0)
-        self.labdb.show()
+            self.butto = hildon.DateButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+            self.butto.set_text("To", "")
+            self.butto.connect("value-changed", listall, True)
+            datebox.pack_start(self.butto, True, True, 0)
+            self.butto.show()
 
-        butgrpevt = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "View Events by Type")
-        butgrpevt.connect("clicked", viewevt)
-        left.pack_end(butgrpevt, False, False, 0)
-        butgrpevt.show()
-        butgrpnum = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "View Events by User")
-        butgrpnum.connect("clicked", viewuid)
-        left.pack_end(butgrpnum, False, False, 0)
-        butgrpnum.show()
-        butcsv = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Export to CSV-File")
-        butcsv.connect("clicked", export_csv)
-        left.pack_end(butcsv, False, False, 0)
-        butcsv.show()
+            butdate = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "View All")
+            butdate.connect("clicked", listall)
+            datebox.pack_start(butdate, True, True, 0)
+            butdate.show()
 
-        searches = gtk.HBox(False, 0)
-        self.entry = hildon.Entry(0)
-        self.entry.set_max_length(100)
-        butsearch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Find")
-        butsearch.connect("clicked", searchall)
-        searches.pack_start(self.entry, True, True, 0)
-        searches.pack_start(butsearch, True, True, 0)
-        left.pack_end(searches, False, False, 0)
-        self.entry.show()
-        butsearch.show()
-        searches.show()
+            boxlines.pack_start(datebox, False, False, 0)
+            datebox.show()
 
-        left.show()
+            boxlines.show()
 
-        separator = gtk.VSeparator()
-        separator.show()
+            left = gtk.VBox(False, 0)
 
-        columns.pack_start(left, True, True, 0)
-        columns.pack_start(separator, False, False, 4)
-        columns.pack_start(boxlines, True, True, 0)
-        columns.show()
-        self.window.add(columns)
+            self.butcharch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Switch to Live-Database")
+            self.butcharch.connect("clicked", change_db)
+            left.pack_start(self.butcharch, False, False, 0)
+            self.butcharch.show()
+            self.labdb = gtk.Label()
+            self.labdb.set_markup("You are viewing:\n<big><b><i>The Archive</i></b></big>")
+            self.labdb.set_justify(gtk.JUSTIFY_CENTER)
+            left.pack_start(self.labdb, False, False, 0)
+            self.labdb.show()
 
+            butgrpevt = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "View Events by Type")
+            butgrpevt.connect("clicked", viewevt)
+            left.pack_end(butgrpevt, False, False, 0)
+            butgrpevt.show()
+            butgrpnum = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "View Events by User")
+            butgrpnum.connect("clicked", viewuid)
+            left.pack_end(butgrpnum, False, False, 0)
+            butgrpnum.show()
+            butcsv = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Export to CSV-File")
+            butcsv.connect("clicked", export_csv)
+            left.pack_end(butcsv, False, False, 0)
+            butcsv.show()
+
+            searches = gtk.HBox(False, 0)
+            self.entry = hildon.Entry(0)
+            self.entry.set_max_length(100)
+            butsearch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Find")
+            butsearch.connect("clicked", searchall)
+            searches.pack_start(self.entry, True, True, 0)
+            searches.pack_start(butsearch, True, True, 0)
+            left.pack_end(searches, False, False, 0)
+            self.entry.show()
+            butsearch.show()
+            searches.show()
+
+            left.show()
+
+            separator = gtk.VSeparator()
+            separator.show()
+
+            columns.pack_start(left, True, True, 0)
+            columns.pack_start(separator, False, False, 4)
+            columns.pack_start(boxlines, True, True, 0)
+            columns.show()
+            self.window.add(columns)
+
+        else:
+          infobox = gtk.VBox(False, 0)
+          infolabel = gtk.Label("Error: eventlogger database not found.\nUpdate maemo 5 PR 1.2, or use glogarchive 0.7.")
+          infobox.pack_start(infolabel, True, True, 0)
+          infolabel.show()
+          infobox.show()
+          self.window.add(infobox)
+          self.allok = False
         self.window.show()
 
 def archive(widget):
@@ -193,12 +238,12 @@ def archive(widget):
       curnew = conn2.cursor()
       curins = conn2.cursor()
 
-      curnew.execute("select service_id, event_type_id, storage_time, start_time, end_time, is_read, flags, bytes_sent, bytes_received, local_uid, local_name, remote_uid, channel, free_text, group_uid from events")
+      curnew.execute("select service_id, event_type_id, storage_time, start_time, end_time, is_read, flags, bytes_sent, bytes_received, local_uid, local_name, remote_uid, channel, free_text, group_uid, outgoing, mc_profile from events")
       allnew = curnew.fetchall()
-      cur.execute("select service_id, event_type_id, storage_time, start_time, end_time, is_read, flags, bytes_sent, bytes_received, local_uid, local_name, remote_uid, channel, free_text, group_uid from events")
+      cur.execute("select service_id, event_type_id, storage_time, start_time, end_time, is_read, flags, bytes_sent, bytes_received, local_uid, local_name, remote_uid, channel, free_text, group_uid, outgoing, mc_profile from events")
       for row in cur: 
         if row not in allnew:
-          curins.execute("insert into events (service_id, event_type_id, storage_time, start_time, end_time, is_read, flags, bytes_sent, bytes_received, local_uid, local_name, remote_uid, channel, free_text, group_uid) values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)", row)
+          curins.execute("insert into events (service_id, event_type_id, storage_time, start_time, end_time, is_read, flags, bytes_sent, bytes_received, local_uid, local_name, remote_uid, channel, free_text, group_uid, outgoing, mc_profile) values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)", row)
           label = gtk.Label("insert to events... type: %s, timestamp: %s" % (row[1], row[3]))
           label.set_alignment(0, 0)
           ui.outlines.pack_start(label, False, False, 0)
@@ -228,7 +273,7 @@ def archive(widget):
       curnew.close()
       curins.close()
     else:
-      label = gtk.Label("Archive not found, copying all from el.db")
+      label = gtk.Label("Archive not found, copying all from el-v1.db")
       label.set_alignment(0, 0)
       ui.outlines.pack_start(label, False, False, 0)
       label.show()
@@ -261,7 +306,7 @@ def listall(widget, filter = False):
     conn = sqlite3.connect(pfad)
     cur = conn.cursor()
     if filter == False:
-      cur.execute("select events.event_type_id, count(events.id) from events group by events.event_type_id order by events.event_type_id")
+      cur.execute("select events.event_type_id, count(events.id), events.outgoing from events group by events.event_type_id, events.outgoing order by events.event_type_id, events.outgoing")
       ui.viewall = True
     else:
       ui.viewall = False
@@ -273,10 +318,10 @@ def listall(widget, filter = False):
       daten2 = "%d-%02d-%02d" % (byear, bmonth, bday)
       stampfrom = time.mktime(time.strptime(daten1, "%Y-%m-%d"))
       stampto = time.mktime(time.strptime(daten2+" 23:59:59", "%Y-%m-%d %H:%M:%S"))
-      cur.execute("select events.event_type_id, count(events.id) from events where events.start_time >= ? and events.start_time <= ? group by events.event_type_id order by events.event_type_id", (stampfrom, stampto))
+      cur.execute("select events.event_type_id, count(events.id), events.outgoing from events where events.start_time >= ? and events.start_time <= ? group by events.event_type_id, events.outgoing order by events.event_type_id, events.outgoing", (stampfrom, stampto))
     for row in cur:
       sumzeile = gtk.HBox(False, 0)
-      label1 = gtk.Label("%s:" % (gettype(row[0])))
+      label1 = gtk.Label("%s:" % (gettype(row[0], row[2])))
       label1.set_alignment(0, 0)
       label2 = gtk.Label("%d" % (row[1]))
       label2.set_alignment(0, 0)
@@ -323,7 +368,7 @@ def viewuid(widget):
       ol2 = "%d events, last: %s" % (row[0], lasttime)
       button.set_text(ol1, ol2)
       button.set_alignment(0, 0, 0, 0)
-      button.connect("clicked", viewdetail, row[4], "user")
+      button.connect("clicked", viewdetail, row[4], 0, "user")
       gruppen.pack_start(button, False, False, 0)
       button.show()
 
@@ -361,11 +406,19 @@ def viewevt(widget):
     for row in cur:
       button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
       button.set_style(hildon.BUTTON_STYLE_PICKER)
-      button.set_text(gettype(row[0]), row[1])
+      button.set_text(gettype(row[0], 0), row[1])
       button.set_alignment(0, 0, 0, 0)
-      button.connect("clicked", viewdetail, row[0], "event")
+      button.connect("clicked", viewdetail, row[0], 0, "event")
       gruppen.pack_start(button, False, False, 0)
       button.show()
+      if row[0] == 1 or row[0] == 5 or row[0] == 7:
+        button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        button.set_style(hildon.BUTTON_STYLE_PICKER)
+        button.set_text(gettype(row[0], 1), row[1])
+        button.set_alignment(0, 0, 0, 0)
+        button.connect("clicked", viewdetail, row[0], 1, "event")
+        gruppen.pack_start(button, False, False, 0)
+        button.show()
 
     gruppen.show()
     scrolled_window.show()
@@ -379,7 +432,7 @@ def viewevt(widget):
     label.show()
     hildon.hildon_banner_show_information(ui.window, "", "No Archive found!")
 
-def viewdetail(widget, did, viewtype):
+def viewdetail(widget, did, inout, viewtype):
   if ui.archivedb == True:
     pfad = ARCHIVE_PATH
   else:
@@ -397,13 +450,13 @@ def viewdetail(widget, did, viewtype):
   conn = sqlite3.connect(pfad)
   cur = conn.cursor()
   if viewtype == "user":
-    cur.execute("select Events.event_type_id, Events.start_time, Events.free_text, Events.remote_uid from Events where substr(Events.remote_uid, -7) = ? order by Events.start_time desc", (did,))
+    cur.execute("select Events.event_type_id, Events.start_time, Events.free_text, Events.remote_uid, Events.outgoing from Events where substr(Events.remote_uid, -7) = ? order by Events.start_time desc", (did,))
   else:
-    cur.execute("select Remotes.remote_name, Events.start_time, Events.free_text, Events.remote_uid from Events left join Remotes on Events.remote_uid = Remotes.remote_uid where Events.event_type_id = ? order by Events.start_time desc", (did,))
+    cur.execute("select Remotes.remote_name, Events.start_time, Events.free_text, Events.remote_uid, Events.outgoing from Events left join Remotes on Events.remote_uid = Remotes.remote_uid where Events.event_type_id = ? and Events.outgoing = ? order by Events.start_time desc", (did,inout))
   for row in cur:
     lasttime = time.strftime("%d.%m.%Y %H:%M:%S", time.localtime(row[1]))
     if viewtype == "user":
-      ol1 = "<b>%s</b> <small>(%s, %s)</small>" % (gettype(row[0]), cgi.escape(row[3]), lasttime)
+      ol1 = "<b>%s</b> <small>(%s, %s)</small>" % (gettype(row[0], row[4]), cgi.escape(row[3]), lasttime)
     else:
       if row[0] == None:
         ol1 = "%s <small>(%s)</small>" % (cgi.escape(row[3]), lasttime)
@@ -446,13 +499,13 @@ def searchall(widget):
   
     conn = sqlite3.connect(pfad)
     cur = conn.cursor()
-    cur.execute("select Remotes.remote_name, Events.start_time, Events.free_text, Events.remote_uid, Events.event_type_id from Events left join Remotes on Events.remote_uid = Remotes.remote_uid where Events.free_text like ? or Events.remote_uid like ? or Remotes.remote_name like ? order by Events.start_time desc", (sstr, sstr, sstr))
+    cur.execute("select Remotes.remote_name, Events.start_time, Events.free_text, Events.remote_uid, Events.event_type_id, Events.outgoing from Events left join Remotes on Events.remote_uid = Remotes.remote_uid where Events.free_text like ? or Events.remote_uid like ? or Remotes.remote_name like ? order by Events.start_time desc", (sstr, sstr, sstr))
     for row in cur:
       lasttime = time.strftime("%d.%m.%Y %H:%M:%S", time.localtime(row[1]))
       if row[0] == None:
-        ol1 = "%s: %s <small>(%s)</small>" % (gettype(row[4]), cgi.escape(row[3]), lasttime)
+        ol1 = "%s: %s <small>(%s)</small>" % (gettype(row[4], row[5]), cgi.escape(row[3]), lasttime)
       else:
-        ol1 = "%s: %s <small>(%s, %s)</small>" % (gettype(row[4]), cgi.escape(row[0]), cgi.escape(row[3]), lasttime)
+        ol1 = "%s: %s <small>(%s, %s)</small>" % (gettype(row[4], row[5]), cgi.escape(row[0]), cgi.escape(row[3]), lasttime)
       if row[2] != None: ol1 = ol1 + "\n<small><i>" + cgi.escape(row[2]) + "</i></small>"
       button = gtk.Label()
       button.set_markup(ol1)
@@ -486,8 +539,8 @@ def export_csv(widget):
     conn = sqlite3.connect(pfad)
     cur = conn.cursor()
     archcsv = csv.writer(csvfile, delimiter=';', quoting=csv.QUOTE_NONNUMERIC)
-    archcsv.writerow(['ID', 'EventTypes.name', 'storage_time', 'start_time', 'end_time', 'is_read', 'flags', 'bytes_sent', 'bytes_received', 'local_uid', 'local_name', 'remote_uid', 'remote_name', 'channel', 'free_text', 'group_uid'])
-    cur.execute("SELECT Events.id, EventTypes.name, Events.storage_time, Events.start_time, Events.end_time, Events.is_read, Events.flags, Events.bytes_sent, Events.bytes_received, Events.local_uid, Events.local_name, Events.remote_uid, Remotes.remote_name, Events.channel, Events.free_text, Events.group_uid FROM Events LEFT JOIN EventTypes ON Events.event_type_id = EventTypes.id LEFT JOIN Remotes ON Events.remote_uid = Remotes.remote_uid ORDER BY Events.start_time")
+    archcsv.writerow(['ID', 'EventTypes.name', 'Events.Outgoing', 'storage_time', 'start_time', 'end_time', 'is_read', 'flags', 'bytes_sent', 'bytes_received', 'local_uid', 'local_name', 'remote_uid', 'remote_name', 'channel', 'free_text', 'group_uid'])
+    cur.execute("SELECT Events.id, EventTypes.name, Events.outgoing, Events.storage_time, Events.start_time, Events.end_time, Events.is_read, Events.flags, Events.bytes_sent, Events.bytes_received, Events.local_uid, Events.local_name, Events.remote_uid, Remotes.remote_name, Events.channel, Events.free_text, Events.group_uid FROM Events LEFT JOIN EventTypes ON Events.event_type_id = EventTypes.id LEFT JOIN Remotes ON Events.remote_uid = Remotes.remote_uid ORDER BY Events.start_time")
     for row in cur:
       archcsv.writerow(row)
     hildon.hildon_banner_show_information(ui.window, "", "File saved to:\n"+savefile)
@@ -520,18 +573,25 @@ def change_db(widget):
   else:
     listall(ui, True)
 
-def gettype(typename):
-  if typename == 1: return "in CALL"
-  if typename == 2: return "out CALL"
+def gettype(typename, inout):
+  if typename == 1 and inout == 0: return "in CALL"
+  if typename == 1 and inout == 1: return "out CALL"
   if typename == 3: return "missed CALL"
-  if typename == 4: return "voicemail CALL"
-  if typename == 5: return "in CHAT"
-  if typename == 6: return "out CHAT"
-  if typename == 7: return "in SMS"
-  if typename == 8: return "out SMS"
+  if typename == 4: return "voicemail"
+  if typename == 5 and inout == 0: return "in CHAT"
+  if typename == 5 and inout == 1: return "out CHAT"
+  if typename == 7 and inout == 0: return "in SMS"
+  if typename == 7 and inout == 1: return "out SMS"
+  if typename == 8: return "notice"
+  if typename == 9: return "action msg"
+  if typename == 10: return "autoreply msg"
+  if typename == 11: return "groupchat joined"
+  if typename == 12: return "groupchat leave"
+  if typename == 13: return "groupchat topic change"
   return "unknown type"
 
 if __name__ == "__main__":
   ui = fenster()
-  listall(ui)
+  if ui.allok == True:
+    listall(ui)
   gtk.main()
